Package: EEM
Type: Package
Title: Read and Preprocess Fluorescence Excitation-Emission Matrix
        (EEM) Data
Version: 1.1.1
Date: 2016-04-21
Author: Vipavee Trivittayasil
Maintainer: Vipavee Trivittayasil <vipavee.tri@gmail.com>
Description: Read raw EEM data and prepares them for further analysis.
Depends: R (>= 3.0.0)
Imports: tools, reshape2, graphics, colorRamps, utils, R.utils, sp,
        ggplot2
Suggests: stats, pls, knitr, testthat
VignetteBuilder: knitr
License: GPL-3
URL: https://github.com/chengvt/EEM
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2016-04-21 06:22:35 UTC; Cheng
Repository: CRAN
Date/Publication: 2016-04-21 13:47:18
Built: R 4.6.0; ; 2026-04-28 02:42:00 UTC; unix
