# Generated by roxygen2: do not edit by hand

S3method("[",EEM)
S3method(c,EEM)
S3method(cutEEM,EEM)
S3method(cutEEM,EEMweight)
S3method(drawEEM,EEM)
S3method(drawEEM,EEMweight)
S3method(drawEEM,data.frame)
S3method(drawEEM,matrix)
S3method(drawEEM,numeric)
S3method(drawEEMgg,EEM)
S3method(drawEEMgg,EEMweight)
S3method(findLocalMax,EEM)
S3method(findLocalMax,internal)
S3method(findLocalMax,matrix)
S3method(findLocalMax,numeric)
S3method(fold,data.frame)
S3method(fold,matrix)
S3method(fold,numeric)
S3method(fold,tbl)
S3method(fold,tbl_df)
S3method(print,EEM)
S3method(summary,EEM)
export(commonizeEEM)
export(cutEEM)
export(delScattering)
export(delScattering2)
export(drawEEM)
export(drawEEMgg)
export(drawEEMgg_internal)
export(findLocalMax)
export(fold)
export(generateColor)
export(generatePoint)
export(getEM)
export(getEX)
export(getLoading)
export(getReg)
export(normalize)
export(plotLoading)
export(plotReg)
export(plotScore)
export(plotScorem)
export(prcompname)
export(readEEM)
export(unfold)
import(ggplot2)
importFrom(R.utils,isDirectory)
importFrom(R.utils,isFile)
importFrom(colorRamps,matlab.like)
importFrom(grDevices,contourLines)
importFrom(graphics,abline)
importFrom(graphics,filled.contour)
importFrom(graphics,legend)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(reshape2,acast)
importFrom(reshape2,melt)
importFrom(sp,point.in.polygon)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,read.delim)
